aboutsummaryrefslogtreecommitdiff
path: root/src/validation.h
diff options
context:
space:
mode:
authorMarcoFalke <*~=`'#}+{/-|&$^_@721217.xyz>2023-07-04 17:09:13 +0200
committerMarcoFalke <*~=`'#}+{/-|&$^_@721217.xyz>2023-09-15 14:34:17 +0200
commit9999b89cd37fb2a23c5ebcd91d9cb31d69375933 (patch)
tree3ded8f9c6e98d3ba651d6261851c20d5d7312c5c /src/validation.h
parentfa389d902fbf5fac19fba8c5d0c5e0a25f15ca63 (diff)
downloadbitcoin-9999b89cd37fb2a23c5ebcd91d9cb31d69375933.tar.xz
Make BufferedFile to be a CAutoFile wrapper
This refactor allows to forward some calls to the underlying CAutoFile, instead of re-implementing the logic in the buffered file.
Diffstat (limited to 'src/validation.h')
-rw-r--r--src/validation.h5
1 files changed, 2 insertions, 3 deletions
diff --git a/src/validation.h b/src/validation.h
index f1ff6bb671..e453d5aaae 100644
--- a/src/validation.h
+++ b/src/validation.h
@@ -607,7 +607,6 @@ public:
bool ResizeCoinsCaches(size_t coinstip_size, size_t coinsdb_size)
EXCLUSIVE_LOCKS_REQUIRED(::cs_main);
-
/**
* Update the on-disk chain state.
* The caches and indexes are flushed depending on the mode we're called with
@@ -1087,14 +1086,14 @@ public:
* -loadblock= option. There's no unknown-parent tracking, so the last two arguments are omitted.
*
*
* @param[in] fileIn FILE handle to file containing blocks to read
* @param[in] dbp (optional) Disk block position (only for reindex)
* @param[in,out] blocks_with_unknown_parent (optional) Map of disk positions for blocks with
* unknown parent, key is parent block hash
* (only used for reindex)
* */
void LoadExternalBlockFile(
- FILE* fileIn,
+ CAutoFile& file_in,
FlatFilePos* dbp = nullptr,
std::multimap<uint256, FlatFilePos>* blocks_with_unknown_parent = nullptr);
@@ -1087,14 +1086,14 @@ public:
*
*
- * @param[in] fileIn FILE handle to file containing blocks to read
+ * @param[in] file_in File containing blocks to read
* @param[in] dbp (optional) Disk block position (only for reindex)
* @param[in,out] blocks_with_unknown_parent (optional) Map of disk positions for blocks with